﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ThinkGeo.MapSuite.WpfDesktopEdition;
using ThinkGeo.MapSuite.Core;

namespace tgdemo
{
    internal class OverlayCollection : Overlay
    {
        public Dictionary<string, Overlay> Overlays { get; private set; }

        public OverlayCollection()
        {
            this.Overlays = new Dictionary<string, Overlay>();
            this.Overlays.Add(Guid.NewGuid().ToString(), new LayerOverlay());
            this.Overlays.Add(Guid.NewGuid().ToString(), new MyMarkerOverlay());

            foreach (Overlay o in this.Overlays.Values)
                this.OverlayCanvas.Children.Add(o.OverlayCanvas);
        }

        protected override void DrawCore(RectangleShape targetExtent, RefreshType refreshType)
        {
            foreach (Overlay o in this.Overlays.Values)
            {
                o.MapArguments = this.MapArguments;
                o.Draw(targetExtent, refreshType);
            }
        }

        protected override void PanToCore(RectangleShape targetExtent)
        {
            foreach (Overlay o in this.Overlays.Values)
            {
                o.MapArguments = this.MapArguments;
                o.PanTo(targetExtent);
            }
        }

        protected override RectangleShape GetBoundingBoxCore()
        {
            List<RectangleShape> r = new List<RectangleShape>();
            foreach (Overlay o in this.Overlays.Values)
                r.Add(o.GetBoundingBox());

            RectangleShape[] rects = r.ToArray();
            return ExtentHelper.GetBoundingBoxOfItems(rects);
        }
    }
}
